************************
sunpy core Documentation
************************

The sunpy core package is a community-developed, free and open-source solar
data analysis environment for Python.

.. panels::

    Getting started
    ^^^^^^^^^^^^^^^
    .. toctree::
      :maxdepth: 1

      installation
      guide/index
      generated/gallery/index
      code_ref/index
      whatsnew/index

    ---

    Other info
    ^^^^^^^^^^
    .. toctree::
      :maxdepth: 1

      about
      code_ref/known_issues
      code_ref/stability
      dev_guide/index
